@@ -41,8 +41,8 @@
 #'   default.
 #' @param \dots Additional arguments passed to \code{\link[pander]{pander}}.
 #'
-#' @return A matrix object containing the statistics, with extra attributes used by
-#'   \pkg{summarytool}'s print method.
+#' @return A nn object of classes \code{matrix} and \code{summarytools} containing 
+#'   the statistics, with extra attributes used by \link{print} method.
 #'
 #' @examples
 #' data(exams)
@@ -211,7 +211,7 @@ descr <- function(x, stats = st_options('descr.stats'), na.rm = TRUE,
                        ifelse("max"  %in% stats, max(variable, na.rm=na.rm), NA),
                        ifelse("mad"  %in% stats, mad(variable, na.rm=na.rm), NA),
                        ifelse("iqr"  %in% stats, IQR(variable, na.rm=na.rm), NA),
-                       ifelse("cv"   %in% stats, variable.mean / variable.sd, NA),
+                       ifelse("cv"   %in% stats, variable.sd / variable.mean, NA),
                        ifelse("skewness"    %in% stats, skewness(variable, na.rm=na.rm), NA),
                        ifelse("se.skewness" %in% stats,
                               sqrt((6*n_valid*(n_valid-1)) / ((n_valid-2)*(n_valid+1)*(n_valid+3))), NA),
@@ -290,7 +290,7 @@ descr <- function(x, stats = st_options('descr.stats'), na.rm = TRUE,
           ifelse("med"  %in% stats, weightedMedian(variable, weights_tmp, refine = TRUE, na.rm = na.rm), NA),
           ifelse("max"  %in% stats, max(variable, na.rm = na.rm), NA),
           ifelse("mad"  %in% stats, weightedMad(variable, weights_tmp, refine = TRUE, na.rm = na.rm), NA),
-          ifelse("cv"   %in% stats, variable.mean/variable.sd, NA),
+          ifelse("cv"   %in% stats, variable.sd/variable.mean, NA),
           ifelse("n.valid"   %in% stats, n_valid, NA),
           ifelse("pct.valid" %in% stats, p_valid * 100, NA))
     }
